==> coser-web-1.4.3-sources.jar: fr/ifremer/coser/web/actions/source/SourceDataAction.java <==
/*
 * #%L
 * $Id: SourceDataAction.java 1033 2012-08-09 10:36:21Z echatellier $
 * $HeadURL: http://svn.forge.codelutin.com/svn/coser/tags/coser-1.4.3/coser-web/src/main/java/fr/ifremer/coser/web/actions/source/SourceDataAction.java $
 * %%
 * Copyright (C) 2010 - 2012 Ifremer, Codelutin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package fr.ifremer.coser.web.actions.source;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Locale;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import fr.ifremer.coser.services.WebService;
import fr.ifremer.coser.web.CoserWebException;
import fr.ifremer.coser.web.ServiceFactory;

/**
 * Force le téléchargement du zip.
 * 
 * @author chatellier
 * @version $Revision: 1033 $
 * 
 * Last update : $Date: 2012-08-09 12:36:21 +0200 (Thu, 09 Aug 2012) $
 * By : $Author: echatellier $
 */
public class SourceDataAction extends SourceAction {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3385467755357775199L;

    private static final Log log = LogFactory.getLog(SourceDataAction.class);

    protected boolean accepted;

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    @Override
    public void validate() {

        if (!accepted) {
            addFieldError("accepted", getText("message.quality.notaccepted"));
        }

    }

    @Action(results= {@Result(type="stream", params={"contentType", "application/zip", "inputName", "inputStream", "contentDisposition", "attachment; filename=\"${filename}\""})})
    public String execute() {
        return SUCCESS;
    }

    public String getFilename() {
        return "source.zip";
    }

    public InputStream getInputStream() {
        WebService webService = ServiceFactory.getWebService();

        Locale locale = getLocale();

        InputStream input = null;
        try {
            
            File sourceZip = webService.getSourceZip(zone, locale);
            input = new FileInputStream(sourceZip);
        } catch (Exception ex) {
            if (log.isErrorEnabled()) {
                log.error("Can't get file data", ex);
            }
            throw new CoserWebException("Can't get source zip file", ex);
        }
        
        return input;
    }
}

==> coser-web-1.5.2-sources.jar: fr/ifremer/coser/web/actions/source/SourceDataAction.java <==
/*
 * #%L
 * Coser :: Web
 * %%
 * Copyright (C) 2010 - 2012 Ifremer, Codelutin, Chatellier Eric, Chemit Tony
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package fr.ifremer.coser.web.actions.source;

import fr.ifremer.coser.result.result.FileResult;
import fr.ifremer.coser.result.request.ExtractRawDataRequest;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import java.io.InputStream;

/**
 * Force le téléchargement du zip.
 *
 * @author chatellier
 * @version $Revision$
 *          <p/>
 *          Last update : $Date$
 *          By : $Author$
 */
public class SourceDataAction extends SourceAction {

    /** serialVersionUID. */
    private static final long serialVersionUID = 3385467755357775199L;

    protected boolean accepted;

    protected FileResult result;

    public void setAccepted(boolean accepted) {
        this.accepted = accepted;
    }

    // used by validator
    public boolean isAccepted() {
        return accepted;
    }

    @Action(results = {@Result(type = "stream", params = {"contentType", "application/zip", "contentDisposition", "attachment; filename=\"${filename}\""})})
    public String execute() {

        ExtractRawDataRequest request = requestBuilder(ExtractRawDataRequest.class).
                addFacade(facade).
                addZone(zone).
                toRequest();
        result = getService().toFirstFileResult(request);
        return SUCCESS;
    }

    public String getFilename() {
        return "source.zip";
    }

    public InputStream getInputStream() {
        return result.getInputStream();
    }

}
